** -----------------------------------------------------------------------------
** This file estimates the set of moments used in estimating the parameters 
** in the WL problem and their covariance matrix.
** -----------------------------------------------------------------------------


drop _all
clear matrix
cd "C:\EMar"



* ------------------------------------------------------------------------------
* Routines 
*

* Calculate moments

cap program drop WLmoments
program define WLmoments

	local i=$i

	
	* Quantiles of the distribution of lYres
	* (calculate before bootstrapping only: `i'=0 )

	if (`i'==0) {
		foreach g of global gender {
		forvalues s=1/3 {

			* those marrying at some point
			gen d = (inrange(`g'age,25,35) & everC==1 & `g's==`s' & `g'dE==1 & `g'lYres<.) /// 
			    if `g'_insampleWL==1 & `g'wklife==1
			centile `g'lYres if d==1, c(10 25 50 75 90)
			forvalues p=1/5 {
				global p`p'C_`g's`s' = r(c_`p')
			}
			cap drop d

			* those remaining single
			gen d = (inrange(`g'age,25,35) & everC==0 & `g's==`s' & `g'dE==1 & `g'lYres<.) ///
			    if `g'_insampleWL==1 & `g'wklife==1
			centile `g'lYres if d==1, c(10 25 50 75 90)
			forvalues p=1/5 {
				global p`p'S_`g's`s' = r(c_`p')
			}
			cap drop d

			* all, for joint distribution in couples
			forvalues s=1/3 {
				gen d = (inrange(`g'age,25,50) & `g's==`s' & `g'dE==1 & `g'lYres<.) ///
				    if `g'_insampleWL==1 & `g'wklife==1
				centile `g'lYres if d==1, c(30 70)
				forvalues p=1/2 {
					global p`p'_`g's`s' = r(c_`p')
				}
				cap drop d
			}
			
		}
		}
	}


	* Marginal distribution of earnings

	foreach g of global gender {
	forvalues s=1/3 {
		
		* Distribution of lYres among young people: marrying at some point
		gen d = (inrange(`g'age,25,35) & everC==1 & `g's==`s' & `g'dE==1 &      ///
		         `g'lYres<.) if `g'_insampleWL==1 & `g'wklife==1
		sum `g'lYres if d==1
		global EC_`g's`s'_`i' = r(mean)
		global vC_`g's`s'_`i' = r(Var)
		forvalues p=1/5 {
			gen d`p' = (`g'lYres<${p`p'C_`g's`s'}) if d==1
			sum d`p'
			global p`p'C_`g's`s'_`i' = r(mean)
			qui cap drop d`p'
		}
		cap drop d
		

		* Distribution of lYres among young people: not marrying
		gen d = (inrange(`g'age,25,35) & everC==0 & `g's==`s' & `g'dE==1 &      ///
		         `g'lYres<.) if `g'_insampleWL==1 & `g'wklife==1
		sum `g'lYres if d==1
		global ES_`g's`s'_`i' = r(mean)
		global vS_`g's`s'_`i' = r(Var)
		forvalues p=1/5 {
			gen d`p' = (`g'lYres<${p`p'S_`g's`s'}) if d==1
			sum d`p'
			global p`p'S_`g's`s'_`i' = r(mean)
			qui cap drop d`p'
		}
		cap drop d

	}
	}
			

	* Joint distribution of earnings in couples
		
	forvalues ms=1/3 {
	forvalues ws=1/3 {

		* means and variances of log earnings residuals
		* by education of both spouses
		foreach g of global gender {
			gen d = (inrange(wage,25,50) & inrange(mage,25,50) & everC==1 &     ///
			         ms==`ms' & ws==`ws' & `g'dE==1 & `g'lYres<. & `g'wklife==1)
			sum `g'lYres if d==1
			global E_`g'ms`ms'ws`ws'_`i' = r(mean)
			global v_`g'ms`ms'ws`ws'_`i' = r(Var)
			drop d
		}

		* joint distribution of earnings by education of both spouses
		gen d = (inrange(wage,25,50) & inrange(mage,25,50) & everC==1 &         ///
		         ms==`ms' & ws==`ws' & mdE==1 & wdE==1 & wlYres<. &             ///
				 mlYres<. & mwklife==1 & wwklife==1)
		gen p1m = (mlYres<${p1_ms`ms'}) if d==1 
		gen p2m = inrange(mlYres,${p1_ms`ms'},${p2_ms`ms'}) if d==1 
		gen p3m = (mlYres>${p2_ms`ms'}) if d==1 
		gen p1w = (wlYres<${p1_ws`ws'}) if d==1 
		gen p2w = inrange(wlYres,${p1_ws`ws'},${p2_ws`ws'}) if d==1 
		gen p3w = (wlYres>${p2_ws`ws'}) if d==1 
				
		forvalues mp=1/3 {
		forvalues wp=1/3 {
			cap drop ingrp
			gen ingrp = (p`mp'm+p`wp'w==2) if d==1
			sum ingrp
			global p`mp'`wp'_ms`ms'ws`ws'_`i' = r(mean)
		}
		}
			
		qui cap drop d p?m p?w
		
	}
	}
	
	
	* Autocorrelation of residuals in log earnings regression

	foreach g of global gender {
		gen `g'v=.
		forvalues s=1/3 {
			sum `g'lYres if `g's==`s'
			replace `g'v = `g'lYres - r(mean) if `g's==`s'
		}

		sort `g'pid wave
		forvalues l=0/3 {
			by `g'pid: gen `g'v0`l' = `g'v*`g'v[_n-`l'] if wave==wave[_n-`l']+`l'
			forvalues s=1/3 {
				sum `g'v0`l' if `g's==`s'
				global Ev0`l'_`g's`s'_`i' = r(mean)
			}
		}
	}


	* Employment rates

	foreach g of global gender {
	forvalues s=1/3 {

		* married individuals: employment by age
		* conditional on gender & education
		gen d = (everC==1 & `g's==`s'  & inrange(`g'age,25,50)) if `g'wklife==1
		regress `g'dE `g'a `g'a2 `g'a3 if d==1
		global dEintC_`g's`s'_`i' = _b[_cons]
		global dEaC_`g's`s'_`i'   = _b[`g'a]
		global dEa2C_`g's`s'_`i'  = _b[`g'a2]
		global dEa3C_`g's`s'_`i'  = _b[`g'a3]
		qui cap drop d
		
		* single individuals: employment by age
		* conditional on gender & education
		gen d = (everC==0 & `g's==`s' & inrange(`g'age,25,50)) ///
		        if `g'_insampleWL==1 & `g'wklife==1
		regress `g'dE `g'a `g'a2 `g'a3 if d==1
		global dEintS_`g's`s'_`i' = _b[_cons]
		global dEaS_`g's`s'_`i'   = _b[`g'a]
		global dEa2S_`g's`s'_`i'  = _b[`g'a2]
		global dEa3S_`g's`s'_`i'  = _b[`g'a3]
		qui cap drop d
		
		* married individuals: distribution of LC employment
		* conditional on gender & education
		gen dtot = (`g'n==1 & `g'N>=5 & `g's==`s' & everC==1 & inrange(`g'age,25,50))
		forvalues d=1/9 {
			gen dtot`d' = (ptot`g'E<0.1*`d') if dtot==1
			sum dtot`d'
			global totdE`d'C_`g's`s'_`i' = r(mean)
		}
		qui cap drop dtot dtot?	

		* single individuals: distribution of LC employment
		* conditional on gender & education
		gen dtot = (`g'n==1 & `g'N>=5 & `g's==`s' & everC==0 & inrange(`g'age,25,50))
		forvalues d=4(2)8 {
			gen dtot`d' = (ptot`g'E<0.1*`d') if dtot==1
			sum dtot`d'
			global totdE`d'S_`g's`s'_`i' = r(mean)
			
		}
		qui cap drop dtot dtot?	

	}
	}

end


* Bootstrap st errors
cap program drop BSmoments
program define BSmoments

	local niter = $BSreplic
	forvalues iter=1/`niter' {
		global i=`iter'
		qui use "data\bsdata.dta", replace
		qui bsample, cluster(i) idcluster(j)
		qui WLmoments
		di "BS iteration ", `iter'
	}
	
end



** -----------------------------------------------------------------------------
** prepare data 
**

qui do "do\earnings process.do"
use "data\BHPSall.dta", replace

keep if m_insampleWL==1 | w_insampleWL==1
keep if (everC==1 & m_insampleWL==1 & w_insampleWL==1) | everC==0

drop if  m_insampleWL==1 & w_insampleWL==1 & ( wSadult>=. | mSadult>=.)
drop if couple ==0 & w_insampleWL==1 & wSadult==.
drop if couple ==0 & m_insampleWL==1 & mSadult==.

drop ms ws
rename mSadult ms
rename wSadult ws

** Construct residual from earnings: log earnings net of age effects 

global gender "m w"
foreach g of global gender {
	gen `g'a     = (`g'age-23)*0.1 if inrange(`g'age,25,50)
	gen `g'a2    = `g'a^2
	gen `g'a3    = `g'a^3
	gen `g'lYres = `g'lY - (`g's==1)*(${`g'ca1}*`g'a+${`g'ca1sq}*`g'a2+${`g'ca1cb}*`g'a3) ///
	                     - (`g's==2)*(${`g'ca2}*`g'a+${`g'ca2sq}*`g'a2+${`g'ca2cb}*`g'a3) ///
						 - (`g's==3)*(${`g'ca3}*`g'a+${`g'ca3sq}*`g'a2+${`g'ca3cb}*`g'a3) if `g'wkl==1
}

** time in employment

foreach g of global gender {
	sort `g'pid wave
	by `g'pid: egen tot`g'E = sum(`g'dE*inrange(`g'age,25,50)*(`g'wklife==1)) if `g'pid<.
	by `g'pid: egen `g'N = sum(inrange(`g'age,25,50)*(`g'wklife==1)) if `g'pid<.
	cap drop `g'n
	by `g'pid: gen `g'n = _n if `g'pid<.
	gen ptot`g'E = tot`g'E/`g'N if `g'N>0
}

sort mpid wpid wave
by mpid wpid: gen i=1 if _n==1
replace i=sum(i)
sort i wave

save "data\bsdata.dta", replace



* ------------------------------------------------------------------------------
* Calculate moments and BS st errors
*

drop _all
clear matrix
global gender "m w"
global i=0
use "data\bsdata.dta", replace
qui WLmoments

global BSreplic = 5000
set seed 874687
BSmoments
erase "data\bsdata.dta"



* ------------------------------------------------------------------------------
* Store moments and their st errors
*
	
local N = $BSreplic+1
qui drop _all
qui set obs `N'
gen n=_n-1

global V "E v p1 p2 p3 p4 p5 dEint dEa dEa2 dEa3 totdE4 totdE6 totdE8"	
foreach m in C S {
foreach v of global V {
foreach g of global gender {
forvalues s=1/3 {
	qui gen `v'`m'_`g's`s' = .
	forvalues i=0/$BSreplic {
		qui replace `v'`m'_`g's`s' = ${`v'`m'_`g's`s'_`i'} if n==`i'
	}
	qui sum `v'`m'_`g's`s' if n>0
	global se_`v'`m'_`g's`s' = r(sd)
}
}
}
}

global V "E_m E_w v_m v_w p11_ p12_ p13_ p21_ p22_ p23_ p31_ p32_ p33_"
foreach v of global V {
forvalues ms=1/3 {
forvalues ws=1/3 {
	qui gen `v'ms`ms'ws`ws' = .
	forvalues i=0/$BSreplic {
		qui replace `v'ms`ms'ws`ws' = ${`v'ms`ms'ws`ws'_`i'} if n==`i'
	}
	qui sum `v'ms`ms'ws`ws' if n>0
	global se_`v'ms`ms'ws`ws' = r(sd)
}
}
}

global V "Ev00_ Ev01_ Ev02_ Ev03_"
foreach v of global V {
foreach g of global gender {
forvalues s=1/3 {
	qui gen `v'`g's`s' = .
	forvalues i=0/$BSreplic {
		qui replace `v'`g's`s' = ${`v'`g's`s'_`i'} if n==`i'
	}
	qui sum `v'`g's`s' if n>0
	global se_`v'`g's`s' = r(sd)
}
}
}

save "moments\b_momentsWL.dta", replace



* ------------------------------------------------------------------------------
* construct list of all moments
*

global V1 "E v p1 p2 p3 p4 p5 dEint dEa dEa2 dEa3 totdE4 totdE6 totdE8"
foreach m in S C {
foreach g of global gender {
forvalues s = 1/3 {
	global V1`m'_`g's`s' ""
	global nV1 = 0
	foreach v of global V1 {
		global V1`m'_`g's`s' "${V1`m'_`g's`s'} `v'`m'_`g's`s'"
		global nV1 = $nV1 + 1
	}
}
}
}

global V2 "Ev00 Ev01 Ev02 Ev03"
foreach g of global gender {
forvalues s = 1/3 {
	global V2_`g's`s' ""
	global nV2 = 0
	foreach v of global V2 {
		global V2_`g's`s' "${V2_`g's`s'} `v'_`g's`s'"
		global nV2 = $nV2 + 1
	}
}
}

global V3 "E_m E_w v_m v_w p11_ p12_ p13_ p21_ p22_ p23_ p31_ p32_ "
forvalues ms = 1/3 {
forvalues ws = 1/3 {
	global V3_ms`ms'ws`ws' ""
	global nV3 = 0
	foreach v of global V3 {
		global V3_ms`ms'ws`ws' "${V3_ms`ms'ws`ws'} `v'ms`ms'ws`ws'"
		global nV3 = $nV3 + 1
	}
}
}



* ------------------------------------------------------------------------------
* calculate varcov matrix
*

use "moments\b_momentsWL.dta", clear
matrix V = J(12*$nV1+6*$nV2+9*$nV3 , 12*$nV1+6*$nV2+9*$nV3, 0)

* V1
local n=1
foreach m in S C {
foreach g of global gender {
forvalues s = 1/3 {
	qui corr ${V1`m'_`g's`s'} if n>0, cov
	matrix V[`n',`n'] = r(C)
	local n=`n'+$nV1
}
}
}

* V2
foreach g of global gender {
forvalues s = 1/3 {
	qui corr ${V2_`g's`s'} if n>0, cov
	matrix V[`n',`n'] = r(C)
	local n=`n'+$nV2
}
}

* V3
forvalues ms = 1/3 {
forvalues ws = 1/3 {
	qui corr ${V3_ms`ms'ws`ws'} if n>0, cov
	matrix V[`n',`n'] = r(C)
	local n=`n'+$nV3
}
}

* V1*V2
local r=12*$nV1+1
local c=1
foreach g of global gender {
forvalues s = 1/3 {

	qui corr ${V1S_`g's`s'} ${V2_`g's`s'} if n>0, cov
	matrix A = r(C)
	matrix V[`r',`c'] = A[ $nV1+1..$nV1+$nV2 , 1..$nV1 ]
	matrix V[`c',`r'] = A[ 1..$nV1 , $nV1+1..$nV1+$nV2 ]

	qui corr ${V1C_`g's`s'} ${V2_`g's`s'} if n>0, cov
	matrix A = r(C)
	matrix V[`r',`c'+6*$nV1] = A[ $nV1+1..$nV1+$nV2 , 1..$nV1 ]
	matrix V[`c'+6*$nV1,`r'] = A[ 1..$nV1 , $nV1+1..$nV1+$nV2 ]

	local r=`r'+$nV2
	local c=`c'+$nV1
	
}
}

* V1*V3: men
local r=12*$nV1+6*$nV2+1
local c=6*$nV1+1
forvalues ms = 1/3 {
	forvalues ws = 1/3 {
		qui corr ${V1C_ms`ms'} ${V3_ms`ms'ws`ws'} if n>0, cov
		matrix A = r(C)
		matrix V[`r',`c'] = A[ $nV1+1..$nV1+$nV3 , 1..$nV1 ]
		matrix V[`c',`r'] = A[ 1..$nV1 , $nV1+1..$nV1+$nV3 ]
		local r = `r'+$nV3
	}
	local c=`c'+$nV1
}

* V1*V3: women
local r=12*$nV1+6*$nV2+1
forvalues ms = 1/3 {
	local c=9*$nV1+1
	forvalues ws = 1/3 {
		qui corr ${V1C_ws`ms'} ${V3_ms`ms'ws`ws'} if n>0, cov
		matrix A = r(C)
		matrix V[`r',`c'] = A[ $nV1+1..$nV1+$nV3 , 1..$nV1 ]
		matrix V[`c',`r'] = A[ 1..$nV1 , $nV1+1..$nV1+$nV3 ]
		local r = `r'+$nV3
		local c = `c'+$nV1
	}
}

* V2*V3: men
local r=12*$nV1+6*$nV2+1
local c=12*$nV1+1
forvalues ms = 1/3 {
	forvalues ws = 1/3 {
		qui corr ${V2_ms`ms'} ${V3_ms`ms'ws`ws'} if n>0, cov
		matrix A = r(C)
		matrix V[`r',`c'] = A[ $nV2+1..$nV2+$nV3 , 1..$nV2 ]
		matrix V[`c',`r'] = A[ 1..$nV2 , $nV2+1..$nV2+$nV3 ]
		local r = `r'+$nV3
	}
	local c=`c'+$nV2
}

* V1*V3: women
local r=12*$nV1+6*$nV2+1
forvalues ms = 1/3 {
	local c=12*$nV1+3*$nV2+1
	forvalues ws = 1/3 {
		qui corr ${V2_ws`ms'} ${V3_ms`ms'ws`ws'} if n>0, cov
		matrix A = r(C)
		matrix V[`r',`c'] = A[ $nV2+1..$nV2+$nV3 , 1..$nV2 ]
		matrix V[`c',`r'] = A[ 1..$nV2 , $nV2+1..$nV2+$nV3 ]
		local r = `r'+$nV3
		local c = `c'+$nV2
	}
}

drop _all
svmat V
saveold "moments\VmomWL.dta", replace version(11)
erase "moments\b_momentsWL.dta"




* ------------------------------------------------------------------------------
* Print moments to files
*

* distribution of earnings among young people

global marital "C S"
global vars "E v p1 p2 p3 p4 p5"
foreach m of global marital {
foreach g of global gender  {

	foreach v of global vars    {
		if ("`v'"=="E" | "`v'"=="v" ) {
			matrix input `v' = ( ${`v'`m'_`g's1_0},  ${se_`v'`m'_`g's1},        ///
			                     ${`v'`m'_`g's2_0},  ${se_`v'`m'_`g's2},        ///
								 ${`v'`m'_`g's3_0},  ${se_`v'`m'_`g's3}  )
		}
		else {
			matrix input `v' = ( ${`v'`m'_`g's1},  ${se_`v'`m'_`g's1},          ///
			                     ${`v'`m'_`g's2},  ${se_`v'`m'_`g's2},          ///
								 ${`v'`m'_`g's3},  ${se_`v'`m'_`g's3}  )
		}
	}
	
	matrix rownames E  = "mean  "
	matrix rownames v  = "var   "
	matrix rownames p1 = "Q10   "
	matrix rownames p2 = "Q25   "
	matrix rownames p3 = "Q50   "
	matrix rownames p4 = "Q75   "
	matrix rownames p5 = "Q90   "

	foreach v of global vars    {
		if ("`v'"=="E") {
			estout matrix(`v', fmt(5)) using "moments\lWdist`m'`g'.txt",        ///
				replace style(fixed) mlabels(none) collabels(none)              ///
				title("! log earnings distribution: `g' in `m'")
		}
		else {
			estout matrix(`v', fmt(5)) using "moments\lWdist`m'`g'.txt",        ///
				append style(fixed) mlabels(none) collabels(none)
		}
	}

}
}

* distribution of earnings in couples

global vars "E v"
foreach v of global vars {
forvalues s=1/3 {

	matrix input `v'w`s' = ( ${`v'_wms`s'ws1_0}, ${se_`v'_wms`s'ws1},           ///
	                         ${`v'_wms`s'ws2_0}, ${se_`v'_wms`s'ws2},           ///
							 ${`v'_wms`s'ws3_0}, ${se_`v'_wms`s'ws3} )
	matrix input `v'm`s' = ( ${`v'_mms1ws`s'_0}, ${se_`v'_mms1ws`s'},           ///
	                         ${`v'_mms2ws`s'_0}, ${se_`v'_mms2ws`s'},           ///
							 ${`v'_mms3ws`s'_0}, ${se_`v'_mms3ws`s'} )

	foreach g of global gender  {
		if ("`v'"=="E") matrix rownames `v'`g'`s' = "E, spouseS=`s'"
		if ("`v'"=="v") matrix rownames `v'`g'`s' = "V, spouseS=`s'"

		if (`s'==1 & "`v'"=="E") {
		  estout matrix(`v'`g'`s', fmt(5)) using "moments\lWdistC`g'_smsw.txt", ///
		    replace style(fixed) mlabels(none) collabels(none)                  ///
			title("! mean log earnings distr in couples: `g' by sm x sf")
		}
		else {
		  estout matrix(`v'`g'`s', fmt(5)) using "moments\lWdistC`g'_smsw.txt", ///
		    append style(fixed) mlabels(none) collabels(none)
		}
	}
}	
}

global vars "p11 p12 p13 p21 p22 p23 p31 p32 p33"
forvalues ms=1/3 {
foreach v of global vars {
    matrix input row = ( ${`v'_ms`ms'ws1_0}, ${se_`v'_ms`ms'ws1},               ///
	                     ${`v'_ms`ms'ws2_0}, ${se_`v'_ms`ms'ws2},               ///
						 ${`v'_ms`ms'ws3_0}, ${se_`v'_ms`ms'ws3} )
    matrix rownames row = "`v', mS=`ms'"
    if ("`v'"=="p11" & `ms'==1) {
        estout matrix(row, fmt(5)) using "moments\lWjointC.txt", replace        ///
               style(fixed) mlabels(none) collabels(none)                       ///
			   title("! joint distr of logY: by (mQ,wQ,ms) for ws=1,2,3")
    }
    else {
        estout matrix(row, fmt(5)) using "moments\lWjointC.txt", append         ///
		       style(fixed) mlabels(none) collabels(none)
    }
}
}

* autocorrelation structure of residuals in earnings regression

global vars "Ev00 Ev01 Ev02 Ev03"
foreach g of global gender {

	foreach v of global vars {
		matrix input `v' = ( ${`v'_`g's1_0}, ${se_`v'_`g's1},                   ///
		                     ${`v'_`g's2_0}, ${se_`v'_`g's2},                   ///
							 ${`v'_`g's3_0}, ${se_`v'_`g's3} )
	}

	matrix rownames Ev00 = "var lYres  "
	matrix rownames Ev01 = "1st autocor"
	matrix rownames Ev02 = "2nd autocor"
	matrix rownames Ev03 = "3rd autocor"

	foreach v of global vars    {
		if ("`v'"=="Ev00") {
			estout matrix(`v', fmt(5)) using "moments\lWres`g'.txt", replace    ///
				style(fixed) mlabels(none) collabels(none)                      ///
				title("! Autocorrelation structure residual log(earnings): `g'")
		}
		else {
			estout matrix(`v', fmt(5)) using "moments\lWres`g'.txt", append     ///
				style(fixed) mlabels(none) collabels(none)
		}
	}
}


** employment rates: regressions

global marital "C S"
global vars "dEint dEa dEa2 dEa3"

foreach g of global gender  {
foreach m of global marital {
	
	foreach v of global vars {
		matrix input `v' = ( ${`v'`m'_`g's1_0},  ${se_`v'`m'_`g's1},            ///
		                     ${`v'`m'_`g's2_0},  ${se_`v'`m'_`g's2},            ///
							 ${`v'`m'_`g's3_0},  ${se_`v'`m'_`g's3}  )
	}
		
	matrix rownames dEint  = "reg`m'-interc"
	matrix rownames dEa    = "reg`m'-age  "
	matrix rownames dEa2   = "reg`m'-age2 "
	matrix rownames dEa3   = "reg`m'-age3 "
		
	foreach v of global vars {
		if ("`m'"=="C" & "`v'"=="dEint") {
			estout matrix(`v', fmt(5)) using "moments\Eregr`g'.txt", replace    ///
				style(fixed) mlabels(none) collabels(none)                      ///
				title("! employment regressions: `g' for s=1,2,3")
		}
		else {
			estout matrix(`v', fmt(5)) using "moments\Eregr`g'.txt", append     ///
				style(fixed) mlabels(none) collabels(none)
		}
	}

}
}
		
** employment rates

global marital "C S"
global vars "totdE4 totdE6 totdE8"

foreach g of global gender  {
foreach m of global marital {
		
	foreach v of global vars {
		matrix input `v' = ( ${`v'`m'_`g's1_0},  ${se_`v'`m'_`g's1},            ///
		                     ${`v'`m'_`g's2_0},  ${se_`v'`m'_`g's2},            ///
							 ${`v'`m'_`g's3_0},  ${se_`v'`m'_`g's3}  )
	}

    matrix rownames totdE4 = "dE<.4 `m'"
    matrix rownames totdE6 = "dE<.6 `m'" 
    matrix rownames totdE8 = "dE<.8 `m'" 

	foreach v of global vars {
		if ("`m'"=="C" & "`v'"=="totdE4") {
			estout matrix(`v', fmt(5)) using "moments\Edist`g'.txt", replace    ///
				style(fixed) mlabels(none) collabels(none)                      ///
				title("! employment distribution: `g' for s=1,2,3")
		}
		else {
			estout matrix(`v', fmt(5)) using "moments\Edist`g'.txt", append     ///
				style(fixed) mlabels(none) collabels(none)
		}
	}

}
}


