** -----------------------------------------------------------------------------
** This file draws figures 3 and 4 in the paper
** -----------------------------------------------------------------------------


drop _all
clear matrix
cd "C:\EMar"


** -----------------------------------------------------------------------------
** Figure 3: impact of risk on marital surplus
** data simulations in "results\sensitivityrisk.txt"

set scheme s1color
set obs 9
gen n=_n
gen v = (n-4)*0.2

gen x=.
replace x= -0.074 if n==1
replace x= -0.049 if n==2
replace x= -0.025 if n==3
replace x=  0.000 if n==4
replace x=  0.025 if n==5
replace x=  0.051 if n==6
replace x=  0.077 if n==7
replace x=  0.104 if n==8
replace x=  0.131 if n==9

twoway line x v, lcolor(navy)                                                   ///       
	   xtitle("proportional change in variance of shocks in earnings")          ///
	   ytitle("proportional change in surplus") graphregion(fcolor(white))
graph export "results\risk-surplus.pdf", as(pdf) replace



** -----------------------------------------------------------------------------
** impact on education take-up and frequency of marriage
** data simulations in "sensitivityrisk.txt"

drop _all
infix using "do\risk dict.dct" in 1/10
gen n = _n-1
gen v = (n-4)*0.2 if n>0

forvalues s=1/3 {
	gen ms`s' = 0
	gen ws`s' = 0
	local h1  = `s'
	local h2  = `s'+3
	forvalues ph=0/6 {
		replace ms`s'=ms`s'+pm`h1'w`ph'+pm`h2'w`ph'
		replace ws`s'=ws`s'+pm`ph'w`h1'+pm`ph'w`h2'
	}
	gen ms`s'C=(ms`s'-pm`h1'w0-pm`h2'w0)/ms`s'
	gen ws`s'C=(ws`s'-pm0w`h1'-pm0w`h2')/ws`s'
}

sort n
foreach g in m w {
	gen `g' = `g's1+`g's2+`g's3
	forvalues s=1/3 {
		replace `g's`s'=`g's`s'/`g'
		gen d`g's`s'C_pp   = 100*(`g's`s'C-`g's`s'C[1])
		gen d`g's`s'C_perc = 100*(`g's`s'C/`g's`s'C[1]-1)
		gen d`g's`s'_pp   = 100*(`g's`s'-`g's`s'[1])
		gen d`g's`s'_perc = 100*(`g's`s'/`g's`s'[1]-1)
	}
}

foreach g in m w {
	if "`g'"=="m" {
		local gender "Men"
	}
	else {
		local gender "Women"
	}
	foreach c in pp perc {
		twoway (lpoly d`g's1_`c' v, lcolor(navy) lpattern(solid) deg(1) bw(1))  ///
			   (lpoly d`g's2_`c' v, lcolor(pink) lpattern(dash) deg(1) bw(1))   ///
			   (lpoly d`g's3_`c' v, lcolor(lavender) lpattern(longdash) deg(1) bw(1)), /// 
			   legend(label(1 "Sec") label(2 "HS") label(3 "Univ") rows(1))     ///
			   xtitle("prop change in variance of shocks in earnings")          ///
			   ytitle("change in education (`c')") graphregion(fcolor(white))   ///
			   name(`g's_`c', replace) title("`gender'") nodraw
		twoway (lpoly d`g's1C_`c' v, lcolor(navy) lpattern(solid) deg(2))       ///
			   (lpoly d`g's2C_`c' v, lcolor(pink) lpattern(dash) deg(2))        ///
			   (lpoly d`g's3C_`c' v, lcolor(lavender) lpattern(longdash) deg(2)), /// 
			   legend(label(1 "Sec") label(2 "HS") label(3 "Univ") rows(1))     ///
			   xtitle("prop change in variance of shocks in earnings")          ///
			   ytitle("change in marriage rate (`c')") title("`gender'")        ///
			   graphregion(fcolor(white)) name(`g'C_`c', replace) nodraw
	}
}

grc1leg ms_pp ws_pp, pos(6) rows(1) graphregion(fcolor(white)) ycommon
graph export "results\risk-education_pp.pdf", as(pdf) replace
grc1leg mC_pp wC_pp, pos(6) rows(1) graphregion(fcolor(white)) ycommon
graph export "results\risk-marriagerate_pp.pdf", as(pdf) replace


