** -----------------------------------------------------------------------------
** This file draws figures 1 and 2 in the paper and 5 and 6 in the Web Appendix
** -----------------------------------------------------------------------------


drop _all
clear matrix
cd "C:\EMar"

set scheme s1color
global gender "m f"
foreach g of global gender {

	use "results\simWL.dta", clear

	keep if insample==1 & s`g'>0 & inrange(a, 25, 50)
	gen dE = 1-l`g'
	gen lY = ln(w`g')
	rename s`g' s

	collapse (mean) dE lY, by(a s)

	if ("`g'"=="m") local g1 "Men"
	if ("`g'"=="f") local g1 "Women"
	
	twoway (line dE a if s==1, lcolor(navy)     lpattern(solid))                /// 
		   (line dE a if s==2, lcolor(lavender) lpattern(dash))                 /// 
		   (line dE a if s==3, lcolor(pink)     lpattern(longdash)),            ///
		   legend(label(1 "Sec") label(2 "HS") label(3 "Univ") rows(1))         ///
		   title("`g1'") ytitle("employment rate") xtitle("age")                ///
		   graphregion(fcolor(white)) name(E`g', replace) nodraw  
	twoway (line lY a if s==1, lcolor(navy)     lpattern(solid))                /// 
		   (line lY a if s==2, lcolor(lavender) lpattern(dash))                 /// 
		   (line lY a if s==3, lcolor(pink)     lpattern(longdash)),            ///
		   legend(label(1 "Sec") label(2 "HS") label(3 "Univ") rows(1))         ///
		   title("`g1'") ytitle("log earnings") xtitle("age")                   ///
		   graphregion(fcolor(white)) nodraw name(lY`g', replace)
}

grc1leg Em Ef, pos(6) rows(1) graphregion(fcolor(white)) ycommon
graph export "results\SimEmployment.pdf", as(pdf) replace

grc1leg lYm lYf, pos(6) rows(1) graphregion(fcolor(white)) ycommon
graph export "results\SimEarnings.pdf", as(pdf) replace



** -----------------------------------------------------------------------------
** Fit of model: employment and earnings for men and women in couples and single
** Figures 5 and 6 in Web Appendix
** -----------------------------------------------------------------------------

** BHPS data
use "data\BHPSall.dta", replace
keep if m_insampleWL==1 | w_insampleWL==1
gen data=1
save "data\fit.dta", replace

** sim data
use "results\simWL.dta", clear
keep if insample==1

global vars "s w l"
foreach v of global vars {
	rename `v'f `v'w
}

global vars "w l"
global gender "m w"
foreach g of global gender {

	foreach v of global vars {
		replace `v'`g' = . if s`g'==0
		rename `v'`g' `g'`v'
	}
	replace s`g'=. if s`g'==0
	rename s`g' `g's

	gen `g'    = (`g's<.)
	gen `g'dE  = 1-`g'l if `g'==1
	gen `g'yrY = `g'w if `g'dE==1

}

gen data = 0

** append datasets
append using "data\fit.dta"
save "data\fit.dta", replace



** draw graphs

foreach g of global gender {

	use "data\fit.dta", replace
	keep if `g'==1
	gen age = `g'age
	replace age=a if data==0
	keep if inrange(age, 25, 50)

	gen lY = ln(`g'yrY)
	collapse (mean) `g'dE `g'yrY lY if `g'wklife==1 | data==0, by(age `g's data)

	if ("`g'"=="m") local g1 "men"
	if ("`g'"=="w") local g1 "women"
	
	twoway (line `g'dE a if data==1 & `g's==1, lcolor(navy) lpattern(solid))     ///
		   (line `g'dE a if data==0 & `g's==1, lcolor(navy) lpattern(dash))      /// 
		   (line `g'dE a if data==1 & `g's==2, lcolor(lavender) lpattern(solid)) ///
		   (line `g'dE a if data==0 & `g's==2, lcolor(lavender) lpattern(dash))  /// 
		   (line `g'dE a if data==1 & `g's==3, lcolor(pink) lpattern(solid))     ///
		   (line `g'dE a if data==0 & `g's==3, lcolor(pink) lpattern(dash)),     ///
		   legend(label(1 "Sec") label(3 "HS") label(5 "Univ") order(1 3 5) rows(1)) ///
		   title("`g1'") ytitle("employment rate") xtitle("age")                 ///
		   graphregion(fcolor(white)) nodraw name(E`g', replace) 
	twoway (line lY a if data==1 & `g's==1, lcolor(navy) lpattern(solid))       ///
		   (line lY a if data==0 & `g's==1, lcolor(navy) lpattern(dash))        /// 
		   (line lY a if data==1 & `g's==2, lcolor(lavender) lpattern(solid))   ///
		   (line lY a if data==0 & `g's==2, lcolor(lavender) lpattern(dash))    /// 
		   (line lY a if data==1 & `g's==3, lcolor(pink) lpattern(solid))       ///
		   (line lY a if data==0 & `g's==3, lcolor(pink) lpattern(dash)),       ///
		   legend(label(1 "Sec") label(3 "HS") label(5 "Univ") order(1 3 5) rows(1)) ///
		   title("`g1'") ytitle("log earnings") xtitle("age")                   ///
		   graphregion(fcolor(white)) nodraw name(lY`g', replace)
}
grc1leg Em Ew, pos(6) rows(1) graphregion(fcolor(white)) ycommon
graph export "results\FitEemployment.pdf", as(pdf) replace

grc1leg lYm lYw, pos(6) rows(1) graphregion(fcolor(white)) ycommon
graph export "results\FitEarnings.pdf", as(pdf) replace

erase "data\fit.dta"
